[java-identity-provider COMMIT] in /trunk: idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthnEventIds.java id...

noreply at shibboleth.net noreply at shibboleth.net
Wed Jul 24 23:51:47 EDT 2013


Author: scantor
Date: Wed Jul 24 23:51:47 2013
New Revision: 4617

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4617&view=rev
Log:
IDP-108/160: action to select a flow or reuse a result

Added:
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/SelectAuthenticationFlow.java
      - copied, changed from r4609, trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/SelectAuthenticationWorkflow.java
Modified:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthnEventIds.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/AuthenticationContext.java
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/authn/context/AuthenticationContextTest.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/SelectAuthenticationWorkflow.java

Modified: trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthnEventIds.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthnEventIds.java?rev=4617&r1=4616&r2=4617&view=diff
==============================================================================
--- trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthnEventIds.java (original)
+++ trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthnEventIds.java Wed Jul 24 23:51:47 2013
@@ -26,9 +26,12 @@
     /** ID of event that indicates the AuthenticationContext is missing or corrupt in some way. */
     public static final String INVALID_AUTHN_CTX = "InvalidAuthenticationContext";
 
-    /** ID of event returned if there are no authentication workflow that could be used to authenticate the user. */
-    public static final String NO_POTENTIAL_WORKFLOW = "NoPotentialWorkflow";
+    /** ID of event returned if there are no authentication flows that could be used to authenticate the user. */
+    public static final String NO_POTENTIAL_FLOW = "NoPotentialFlow";
 
+    /** ID of event returned if there no authentication flows that can satisfy the request's requirements. */
+    public static final String NO_REQUESTED_FLOW = "NoRequestedFlow";
+    
     /** ID of event returned if there are no credentials available in the request. */
     public static final String NO_CREDENTIALS = "NoCredentials";
 

Modified: trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/AuthenticationContext.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/AuthenticationContext.java?rev=4617&r1=4616&r2=4617&view=diff
==============================================================================
--- trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/AuthenticationContext.java (original)
+++ trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/context/AuthenticationContext.java Wed Jul 24 23:51:47 2013
@@ -39,6 +39,7 @@
 import org.opensaml.messaging.context.BaseContext;
 
 import com.google.common.base.Objects;
+import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableMap.Builder;
 
@@ -60,16 +61,16 @@
     private boolean isPassive;
     
     /** A non-normative hint some protocols support to indicate who the subject might be. */
-    private String hintedName;
+    @Nullable private String hintedName;
 
     /** Flows that could potentially be used to authenticate the user. */
     @Nonnull @NonnullElements private Map<String, AuthenticationFlowDescriptor> potentialFlows;
     
     /** Flows, in order of preference, that satisfy an explicit requirement from the relying party. */
-    @Nonnull @NonnullElements private ImmutableMap<String, AuthenticationFlowDescriptor> requestedFlows;
-
-    /** Authentication flows associated with a preexisting session and available for (re)use. */
-    @Nonnull @NonnullElements private ImmutableMap<String, AuthenticationFlowDescriptor> activeFlows;
+    @Nonnull @NonnullElements private ImmutableList<AuthenticationFlowDescriptor> requestedFlows;
+
+    /** Authentication results associated with an active session and available for (re)use. */
+    @Nonnull @NonnullElements private ImmutableMap<String, AuthenticationResult> activeResults;
         
     /** Authentication flow being attempted to authenticate the user. */
     @Nullable private AuthenticationFlowDescriptor attemptedFlow;
@@ -99,8 +100,8 @@
             }
         }
 
-        activeFlows = ImmutableMap.of();
-        requestedFlows = ImmutableMap.of();
+        activeResults = ImmutableMap.of();
+        requestedFlows = ImmutableList.of();
     }
 
     /**
@@ -113,34 +114,34 @@
     }
 
     /**
-     * Gets the authentication flows currently active for the subject.
-     * 
-     * @return authentication flows currently active for the subject
-     */
-    @Nonnull @NonnullElements @Unmodifiable public Map<String, AuthenticationFlowDescriptor> getActiveFlows() {
-        return activeFlows;
-    }
-
-    /**

[... 511 lines stripped ...]


More information about the commits mailing list